pub struct AndroidConfig {
pub min_sdk_version: u32,
pub version_code: Option<u32>,
pub auto_increment_version_code: bool,
pub debug_application_id_suffix: Option<String>,
}Expand description
General configuration for the Android target.
Fields
min_sdk_version: u32The minimum API level required for the application to run. The Android system will prevent the user from installing the application if the system’s API level is lower than the value specified.
version_code: Option<u32>The version code of the application. It is limited to 2,100,000,000 as per Google Play Store requirements.
By default we use your configured version and perform the following math: versionCode = version.major * 1000000 + version.minor * 1000 + version.patch
auto_increment_version_code: boolWhether to automatically increment the versionCode on each build.
- If
true, the generator will try to read the lastversionCodefromtauri.propertiesand increment it by 1 for every build. - If
falseor not set, it falls back toversion_codeor semver-derived logic.
Note that to use this feature, you should remove /tauri.properties from src-tauri/gen/android/app/.gitignore so the current versionCode is committed to the repository.
debug_application_id_suffix: Option<String>Application ID suffix to append for debug builds. This allows installing debug and release versions side-by-side on the same device. Example: “.debug” will make debug builds use “com.example.app.debug” as the application ID.