WindowEffectsConfig

Struct WindowEffectsConfig 

pub struct WindowEffectsConfig {
    pub effects: Vec<WindowEffect>,
    pub state: Option<WindowEffectState>,
    pub radius: Option<f64>,
    pub color: Option<Color>,
    pub interactive: bool,
}
The window effects configuration object

Fields

effects: Vec<WindowEffect>

List of Window effects to apply to the Window.

Generally, conflicting effects will apply the first one and ignore the rest but on macOS you can specify one Liquid Glass style and one Visual Effect material at the same time to make Tauri fallback to the latter on macOS 15 and below.

state: Option<WindowEffectState>

Window effect state macOS Only. Ignored for Liquid Glass Effects.

radius: Option<f64>

Window effect corner radius macOS Only

color: Option<Color>

Window effect color.

Platform-specific

interactive: bool

Enables interactive glass behavior, which adds a visual response to user interactions.

macOS 27.0+. Only affects Liquid Glass effects.