WindowEffect

Enum WindowEffect 

pub enum WindowEffect {
Show 27 variants AppearanceBased, Light, Dark, MediumLight, UltraDark, Titlebar, Selection, Menu, Popover, Sidebar, HeaderView, Sheet, WindowBackground, HudWindow, FullScreenUI, Tooltip, ContentBackground, UnderWindowBackground, UnderPageBackground, Mica, MicaDark, MicaLight, Tabbed, TabbedDark, TabbedLight, Blur, Acrylic,
}
Platform-specific window effects

Variants



AppearanceBased

👎Deprecated since macOS 10.14:

You should instead choose an appropriate semantic material.

A default material appropriate for the view’s effectiveAppearance. macOS 10.14-



Light

👎Deprecated since macOS 10.14:

Use a semantic material instead.

macOS 10.14-



Dark

👎Deprecated since macOS 10.14:

Use a semantic material instead.

macOS 10.14-



MediumLight

👎Deprecated since macOS 10.14:

Use a semantic material instead.

macOS 10.14-



UltraDark

👎Deprecated since macOS 10.14:

Use a semantic material instead.

macOS 10.14-



Titlebar

macOS 10.10+



Selection

macOS 10.10+



Menu

macOS 10.11+



Popover

macOS 10.11+



Sidebar

macOS 10.11+



HeaderView

macOS 10.14+



Sheet

macOS 10.14+



WindowBackground

macOS 10.14+



HudWindow

macOS 10.14+



FullScreenUI

macOS 10.14+



Tooltip

macOS 10.14+



ContentBackground

macOS 10.14+



UnderWindowBackground

macOS 10.14+



UnderPageBackground

macOS 10.14+



Mica

Mica effect that matches the system dark preference Windows 11 Only



MicaDark

Mica effect with dark mode but only if dark mode is enabled on the system Windows 11 Only



MicaLight

Mica effect with light mode Windows 11 Only



Tabbed

Tabbed effect that matches the system dark preference Windows 11 Only



TabbedDark

Tabbed effect with dark mode but only if dark mode is enabled on the system Windows 11 Only



TabbedLight

Tabbed effect with light mode Windows 11 Only



Blur

Windows 7/10/11(22H1) Only

Notes

This effect has bad performance when resizing/dragging the window on Windows 11 build 22621.



Acrylic

Windows 10/11 Only

Notes

This effect has bad performance when resizing/dragging the window on Windows 10 v1903+ and Windows 11 build 22000.