Struct tauri_utils::config::Config
source · [−]pub struct Config {
pub schema: Option<String>,
pub package: PackageConfig,
pub tauri: TauriConfig,
pub build: BuildConfig,
pub plugins: PluginConfig,
}Expand description
The Tauri configuration object. It is read from a file where you can define your frontend assets, configure the bundler, enable the app updater, define a system tray, enable APIs via the allowlist and more.
The configuration file is generated by the
tauri init command that lives in
your Tauri application source directory (src-tauri).
Once generated, you may modify it at will to customize your Tauri application.
File Formats
By default, the configuration is defined as a JSON file named tauri.conf.json.
Tauri also supports JSON5 and TOML files via the config-json5 and config-toml Cargo features, respectively.
The JSON5 file name must be either tauri.conf.json or tauri.conf.json5.
The TOML file name is Tauri.toml.
Platform-Specific Configuration
In addition to the default configuration file, Tauri can
read a platform-specific configuration from tauri.linux.conf.json,
tauri.windows.conf.json, and tauri.macos.conf.json
(or Tauri.linux.toml, Tauri.windows.toml and Tauri.macos.toml if the Tauri.toml format is used),
which gets merged with the main configuration object.
Configuration Structure
The configuration is composed of the following objects:
package: Package settingstauri: The Tauri configbuild: The build configurationplugins: The plugins config
{
"build": {
"beforeBuildCommand": "",
"beforeDevCommand": "",
"devPath": "../dist",
"distDir": "../dist"
},
"package": {
"productName": "tauri-app",
"version": "0.1.0"
},
"tauri": {
"allowlist": {
"all": true
},
"bundle": {},
"security": {
"csp": null
},
"updater": {
"active": false
},
"windows": [
{
"fullscreen": false,
"height": 600,
"resizable": true,
"title": "Tauri App",
"width": 800
}
]
}
}Fields
schema: Option<String>The JSON schema for the Tauri config.
package: PackageConfigPackage settings.
tauri: TauriConfigThe Tauri configuration.
build: BuildConfigThe build configuration.
plugins: PluginConfigThe plugins config.