pub trait HeaderAddition {
// Required method
fn add_configured_headers(self, headers: Option<&HeaderConfig>) -> Builder;
}Expand description
A trait which implements on the Builder of the http create
Must add headers defined in the tauri configuration file to http responses
Required Methods
Sourcefn add_configured_headers(self, headers: Option<&HeaderConfig>) -> Builder
fn add_configured_headers(self, headers: Option<&HeaderConfig>) -> Builder
adds all headers defined on the config file, given the current HeaderConfig
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl HeaderAddition for Builder
impl HeaderAddition for Builder
Sourcefn add_configured_headers(self, headers: Option<&HeaderConfig>) -> Builder
fn add_configured_headers(self, headers: Option<&HeaderConfig>) -> Builder
Add the headers defined in the tauri configuration file to http responses
this is a utility function, which is used in the same way as the .header(..) of the rust http library